import com.urbancode.air.AirPluginTool
import com.urbancode.air.CommandHelper

//sdk imports
import com.amazonaws.AmazonServiceException;
import com.amazonaws.auth.AWSCredentials;
import com.amazonaws.auth.BasicAWSCredentials;
import com.amazonaws.services.ec2.AmazonEC2;
import com.amazonaws.services.ec2.AmazonEC2Client;
import com.amazonaws.services.ec2.model.RunInstancesRequest;
import com.amazonaws.services.ec2.model.RunInstancesResult;
import com.amazonaws.services.ec2.model.Placement;
import com.amazonaws.services.ec2.model.Reservation;
import com.amazonaws.services.ec2.model.Instance;

def ch = new CommandHelper(new File('.'));
def apTool = new AirPluginTool(this.args[0], this.args[1]);
def props = apTool.getStepProperties();

def accessKeyId = props['accessKeyId'];
def secretKey = props['secretKey'];
def number = props['number'];
def ami = props['ami'];
def group = props['group'];
def zone = props['zone'];
def keyPair = props['keypair'];

def options = props['options'];

AWSCredentials creds = null;
creds = new BasicAWSCredentials(accessKeyId, secretKey);

AmazonEC2 ec2 = new AmazonEC2Client(creds);

RunInstancesRequest req = new RunInstancesRequest()
                          .withImageId(ami)
                          .withMinCount(Integer.valueOf(number))
                          .withMaxCount(Integer.valueOf(number));

if (keyPair) {
    req = req.withKeyName(keyPair);
}

if (zone) {
    Placement placement = new Placement(zone);
    req = req.withPlacement(placement);
}

if (group) {
    req = req.withSecurityGroups(group.split(','));
}

if (options) {
    req = req.withUserData(options);
}

println "Creating $number instances of $ami";
RunInstancesResult result = ec2.runInstances(req);
List<Instance> instances = result.getReservation().getInstances();

def insts = instances.collect { return it.getInstanceId() };
                          
apTool.setOutputProperty("instances", insts.join(','));
apTool.setOutputProperties();
