import com.urbancode.air.AirPluginTool
import com.urbancode.air.CommandHelper

//sdk imports
import com.amazonaws.AmazonServiceException;
import com.amazonaws.auth.AWSCredentials;
import com.amazonaws.auth.BasicAWSCredentials;
import com.amazonaws.services.ec2.AmazonEC2;
import com.amazonaws.services.ec2.AmazonEC2Client;
import com.amazonaws.services.ec2.model.AuthorizeSecurityGroupIngressRequest;
import com.amazonaws.services.ec2.model.CreateSecurityGroupRequest;
import com.amazonaws.services.ec2.model.IpPermission;
import com.amazonaws.services.ec2.model.DescribeInstancesRequest;
import com.amazonaws.services.ec2.model.DescribeInstancesResult;
import com.amazonaws.services.ec2.model.Reservation;
import com.amazonaws.services.ec2.model.Instance;
import com.amazonaws.services.ec2.model.InstanceState;

def ch = new CommandHelper(new File('.'));
def apTool = new AirPluginTool(this.args[0], this.args[1]);
def props = apTool.getStepProperties();

def accessKeyId = props['accessKeyId'];
def secretKey = props['secretKey'];
def status = props['status'];
def instancess = props['instances'].split(',');
def timeout = Long.valueOf(props['ec2Timeout']);

AWSCredentials creds = null;
creds = new BasicAWSCredentials(accessKeyId, secretKey);

AmazonEC2 ec2 = new AmazonEC2Client(creds);

def badStates = [:];
for (def inst : instancess) {
    badStates.put(inst, "bad");
}

Long startTime = System.currentTimeMillis();
while (!badStates.isEmpty() && System.currentTimeMillis() - startTime < timeout) {
    def newBadStates = [:];
    def instanceIds = badStates.collect { it.getKey() };

    DescribeInstancesRequest req = new DescribeInstancesRequest().withInstanceIds(instanceIds);

    DescribeInstancesResult result = ec2.describeInstances(req);

    List<Instance> instances = new ArrayList<Instance>();
    List<Reservation> reservations = result.getReservations();
    reservations.each { reservation ->
        List<Instance> currInstances = reservation.getInstances();
        instances.addAll(currInstances);
    }

    instanceIds.each { instanceId ->
        Instance instance = instances.find { it.getInstanceId() == instanceId };

        if (!instance.getState().getName().equals(status)) {
            println "Instance " + instance.getInstanceId() + " in bad state: " + instance.state.name;
            newBadStates.put(instanceId, status);
        }
    }
    badStates = newBadStates;
    Thread.sleep(10000);
}

if (badStates.isEmpty()) {
    println "All instances in expected state!";
    System.exit(0);
}
else {
    println "Some instances in wrong state!";
    println badStates;
    System.exit(1);
}
